<!-- 新增编辑弹窗 -->
<template>
    <j-modal
        v-if="visible"
        :title="props.title"
        :maskClosable="false"
        destroy-on-close
        visible
        @ok="submitData"
        @cancel="close"
        okText="确定"
        cancelText="取消"
    >
        <j-form
            layout="vertical"
            ref="formRef"
            :rules="rules"
            :model="formModel"
        >
            <j-form-item label="所属单位" name="institutionId">
                <j-select
                    style="width: 100%"
                    v-model:value="formModel.institutionId"
                    placeholder="请选择单位"
                >
                    <j-select-option
                        v-for="item in institutionData"
                        :key="item.id"
                        :value="item.id"
                    >
                        {{ item.name }}
                    </j-select-option>
                </j-select>
            </j-form-item>
            <j-form-item label="名称" name="name">
                <j-input
                    v-model:value="formModel.name"
                    :maxlength="64"
                    placeholder="请输入名称"
                    allowClear
                />
            </j-form-item>
            <!-- <j-form-item label="备注">
                <j-input
                    v-model:value="formModel.describe"
                    :maxlength="64"
                    placeholder="请输入备注"
                    allowClear
                />
                                    </j-form-item> -->
        </j-form>
    </j-modal>
</template>
<script setup lang="ts" name="modifyModal">
import { PropType } from 'vue';
import { Form, message } from 'jetlinks-ui-components';
import { saveStore, updateStore } from '@/api/warehouse/store';
import { queryInstitutionNoPaging } from '@/api/warehouse/institution';

const emits = defineEmits(['refresh']);
const formRef = ref();
const useForm = Form.useForm;
const props = defineProps({
    formData: {
        type: Object as PropType<Record<string, any>>,
        default: () => {},
    },
    title: {
        type: String,
        defult: '新增区域',
    },
    isAdd: {
        type: Number,
        default: 0,
    },
    isChild: {
        type: Number,
        default: 0,
    },
});
interface formState {
    id?: string;
    name: string;
    institutionId: string;
}
const institutionData = ref<any>([]);
const updateObj = ref({});
const addParams = ref({});
/**
 * 表单数据
 */
const formModel = ref<formState>({
    name: '',
    institutionId: ''
});
const rules = ref({
    name: [{ required: true, message: '请填写库房名称', trigger: 'change' }],
    institutionId: [{ required: true, message: '请选择单位', trigger: 'change' }],
});
const visible = ref(false);
const { resetFields, validate, validateInfos } = useForm(
    formModel.value,
    rules.value,
);

onMounted(() => {
    queryInstitution();
});

/**
 * 查询单位数量，不分页
 */
const queryInstitution = async () => {
    let params = {
        paging: false,
        sorts: [
            { name: 'sortIndex', order: 'asc' },
            { name: 'createTime', order: 'desc' },
        ],
        where: '',
        terms: [],
    };
    const res = await queryInstitutionNoPaging(params);
    if (res.status === 200) {
        institutionData.value = res.result;
    }
};

const filterOption = (input: string, option: any) => {
    return option.value.toLowerCase().indexOf(input.toLowerCase()) >= 0;
};

/**
 * 提交数据
 */
const submitData = async () => {
    formRef.value.validate().then(async () => {
        addParams.value = {};
        // console.log("submitData:", formModel, props);
        if (props.isAdd === 0) {
            addParams.value = {
                ...formModel.value,
            };
            const res = await saveStore(addParams.value);
            if (res.status === 200) {
                message.success('操作成功！');
                visible.value = false;
                emits('refresh');
            } else {
                message.error('操作失败！');
            }
        } else if (props.isAdd === 2) {
            const id = formModel.value.id || '';
            const updateParams = {
                ...formModel.value,
            };

            const res = await updateStore(id, updateParams);
            if (res.status === 200) {
                message.success('操作成功！');
                visible.value = false;
                emits('refresh');
            } else {
                message.error('操作失败！');
            }
        }
    });
};
/**
 * 显示弹窗
 */
const show = async (row: any) => {
    // console.log("show:", row, props.isAdd);
    //新增
    if (props.isAdd === 0) {
        formModel.value = {
            name: '',
            institutionId: ''
        };
        visible.value = true;
    } else if (props.isAdd === 2) {
        updateObj.value = row;
        // 编辑
        formModel.value = {
            id: row.id,
            name: row.name,
            institutionId: row.institutionId
        };
        visible.value = true;
    }
};

/**
 * 排序
 */
const compare = (property: any) => {
    return function (obj1: any, obj2: any) {
        var value1 = obj1[property];
        var value2 = obj2[property];
        return value1 - value2; // 升序
    };
};
/**
 * 关闭弹窗
 */
const close = () => {
    visible.value = false;
    resetFields();
};
//监听项目ID
watch([() => props.isAdd], () => {}, { immediate: false, deep: true });
defineExpose({
    show: show,
});
</script>
<style></style>
